# Photo Stats

![Lint,PyTest, MyPy, and Coverage](https://github.com/djotaku/photo_stats/workflows/Lint,PyTest,%20MyPy,%20and%20Coverage/badge.svg) [![codecov](https://codecov.io/gh/djotaku/photo_stats/branch/master/graph/badge.svg)](https://codecov.io/gh/djotaku/photo_stats)

This project is still in its infancy, but the intention is to have it be a Python package with a bunch of utilities 
for running a variety of stats on your photos.

For now the envisioned output would be to the terminal and generation of graphs. 